//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Kan](index.md)/[ankan](ankan.md)

# ankan

[common]\

@EncodeDefault

val [ankan](ankan.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false

是否为暗杠
